apiVersion: apps/v1
kind: Deployment
metadata:
  annotations:
    tmc.cloud.vmware.com/do-not-delete: "true"
  labels:
    app: wavefront-proxy-tanzu
    name: wavefront-proxy-tanzu
  name: wavefront-proxy-tanzu
  namespace: tanzu-observability-saas
spec:
  replicas: 1
  selector:
    matchLabels:
      app: wavefront-proxy-tanzu
  template:
    metadata:
      annotations:
        configHash: "{{ .ConfigHash }}"
      labels:
        app: wavefront-proxy-tanzu
    spec:
      securityContext:
        runAsNonRoot: true
        runAsUser: 1000
        runAsGroup: 2000
      containers:
        - envFrom:
            - configMapRef:
                name: wavefront-proxy-egress-proxy-config
          env:
            - name: WAVEFRONT_URL
              valueFrom:
                configMapKeyRef:
                  key: wavefront.url
                  name: wavefront-proxy-config
            - name: WAVEFRONT_TOKEN
              valueFrom:
                secretKeyRef:
                  key: wavefront.token
                  name: wavefront-proxy-secret
            - name: WAVEFRONT_PROXY_ARGS
              value: >
                --traceZipkinListenerPorts 9411 $(WAVEFRONT_PROXY_EGRESS_PROXY_ARGS)
                --buffer /wavefront-proxy/buffer
          image: projects.registry.vmware.com/tanzu_observability/proxy:13.0
          imagePullPolicy: IfNotPresent
          name: wavefront-proxy-tanzu
          securityContext:
            allowPrivilegeEscalation: false
            readOnlyRootFilesystem: true
            seccompProfile:
              type: "RuntimeDefault"
            capabilities:
              drop: ["ALL"]
          ports:
            - containerPort: 2878
              protocol: TCP
            - containerPort: 9411
              protocol: TCP
          resources:
            limits:
              cpu: 1000m
              memory: 4Gi
            requests:
              cpu: 100m
              memory: 1Gi
          volumeMounts:
            - name: buffer-volume
              mountPath: /wavefront-proxy
{{- if eq .UseCaCert true }}
            - name: tmc-egress-ca
              mountPath: /tmp/ca
{{- end }}
      volumes:
        - name: buffer-volume
          emptyDir: { }
{{- if eq .UseCaCert true }}
        - name: tmc-egress-ca
          secret:
            secretName: tmc-proxy-secret
            items:
              - key: tls-root-ca-bundle
                path: ca.pem
{{- end }}
